@@ -73,12 +73,13 @@ getCoins <-
     }
     coinnames <-
       dplyr::data_frame(
+        symbol = as.character(coins$symbol),
         name = as.character(coins$name),
         rank = coins$rank,
         slug = coins$slug
       )
-    length <- as.numeric(length(coins$url))
-    zrange <- 1:as.numeric(length(coins$url))
+    length <- as.numeric(length(coins$history_url))
+    zrange <- 1:as.numeric(length(coins$history_url))
     if (is.null(cpu_cores)) {
     cpu_cores <- as.numeric(parallel::detectCores(all.tests = FALSE, logical = TRUE))
     }
@@ -89,7 +90,7 @@ getCoins <-
     progress <- function(n)
       setTxtProgressBar(pb, n)
     opts <- list(progress = progress)
-    attributes <- coins$url
+    attributes <- coins$history_url
     slug <- coins$slug
     message('   If this helps you become rich please consider donating',
             appendLF = TRUE)
